from setuptools import setup, find_packages

setup(
    name = 'AAUtility',
    version='1.0.2',
    description='package utility function in common package',
    url='https://github.com/gauravccloud/AAUtility.git',
    author='Gaurav Sharma',
    author_email='gauravdbdev@gmail.com',
    license='MIT',
    packages=['AAUtility'],
    install_requires=[],
    zip_safe=False
)